@@ -71,7 +71,8 @@ class mysqlUtil:
     # 查询上传文件是否有重复
     def sftp_file_repeat(self,fdesc,fsize,duration):
         if fsize and duration:
-            sql = "select id from sftp_files where fsize={} and  duration={} limit 1".format(fsize,duration)
+            # 判断float相等： abs(duration-123.31)<0.01
+            sql = "select id from sftp_files where fsize={} and  abs(duration-{})<0.01 limit 1".format(fsize,duration)
             connection = self.engine.connect()
             df = pd.read_sql(text(sql), con=connection)
             results = json.loads(df.to_json(orient='records'))
